@@ -4,7 +4,7 @@ import asyncio
 import threading
 import time
 import functools
-from flask import current_app as app
+from . import app
 
 class Processor(threading.Thread):
     def __init__(self):
@@ -16,7 +16,8 @@ class Processor(threading.Thread):
         self._loop.run_forever()
 
     def post_task(self, callback):
-        self._loop.call_soon_threadsafe(callback)
+        self._loop.call_soon_threadsafe(
+            functools.partial(self._do_callback, callback))
 
     def start(self):
         super().start()
@@ -31,6 +32,12 @@ class Processor(threading.Thread):
     def _do_stop(self):
         self._loop.stop()
 
+    def _do_callback(self, callback):
+        try:
+            callback()
+        except Exception as e:
+            app.logger.error('处理任务发生异常', exc_info=True)
+
 def task():
     def decorator(func):
         @functools.wraps(func)
